==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Binary/ClearBits.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+12)
#define CT_v198	((void*)startLabel+40)
#define F0_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+48)
#define FN_NHC_46Binary_46hs_95clearBits	((void*)startLabel+76)
#define CT_v202	((void*)startLabel+128)
#define CF_NHC_46Binary_46hs_95clearBits	((void*)startLabel+136)
#define CT_v209	((void*)startLabel+312)
#define FN_LAMBDA194	((void*)startLabel+364)
#define CT_v213	((void*)startLabel+416)
#define F0_LAMBDA194	((void*)startLabel+424)
#define ST_v204	((void*)startLabel+448)
#define PP_LAMBDA194	((void*)startLabel+469)
#define PC_LAMBDA194	((void*)startLabel+469)
#define ST_v211	((void*)startLabel+469)
#define PP_NHC_46Binary_46hs_95clearBits	((void*)startLabel+496)
#define PC_NHC_46Binary_46hs_95clearBits	((void*)startLabel+496)
#define ST_v200	((void*)startLabel+496)
#define PP_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+520)
#define PC_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+520)
#define ST_v197	((void*)startLabel+520)
#define PS_v201	((void*)startLabel+548)
#define PS_v199	((void*)startLabel+560)
#define PS_v206	((void*)startLabel+572)
#define PS_v205	((void*)startLabel+584)
#define PS_v203	((void*)startLabel+596)
#define PS_v208	((void*)startLabel+608)
#define PS_v207	((void*)startLabel+620)
#define PS_v196	((void*)startLabel+632)
#define PS_v212	((void*)startLabel+644)
#define PS_v210	((void*)startLabel+656)
void FR_NHC_46Binary_46hs_95clearBits_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46Binary[];
extern Node PC_NHC_46Internal_46_95mkIOok2[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PC_NHC_46Internal_46_95apply2[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46Binary[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v198)
,	/* FN_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v197)
,	/* CT_v198: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits_35),2)
, useLabel(PS_v196)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v202)
,	/* FN_NHC_46Binary_46hs_95clearBits: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v201)
, 0
, 0
, 0
, 0
, 110022
, useLabel(ST_v200)
,	/* CT_v202: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95clearBits: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, useLabel(PS_v199)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v209)
,};
Node FN_NHC_46Binary_46clearBits[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(18,HEAP_OFF_N1,11,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v208)
, 0
, 0
, 0
, 0
, useLabel(PS_v207)
, 0
, 0
, 0
, 0
, useLabel(PS_v206)
, 0
, 0
, 0
, 0
, useLabel(PS_v205)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v204)
,	/* CT_v209: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46Binary_46clearBits[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46clearBits),2)
, useLabel(PS_v203)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v213)
,	/* FN_LAMBDA194: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v212)
, 0
, 0
, 0
, 0
, 150011
, useLabel(ST_v211)
,	/* CT_v213: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA194: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA194),1)
, useLabel(PS_v210)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_NHC_46Binary_46clearBits[] = {
 };
Node PC_NHC_46Binary_46clearBits[] = {
 	/* ST_v204: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,99)
, bytes2word(108,101,97,114)
, bytes2word(66,105,116,115)
,	/* PP_LAMBDA194: (byte 1) */
 	/* PC_LAMBDA194: (byte 1) */
 	/* ST_v211: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(97,114,121,46)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
, bytes2word(115,58,49,53)
,	/* PP_NHC_46Binary_46hs_95clearBits: (byte 4) */
 	/* PC_NHC_46Binary_46hs_95clearBits: (byte 4) */
 	/* ST_v200: (byte 4) */
  bytes2word(58,49,49,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,99,108)
, bytes2word(101,97,114,66)
,	/* PP_NHC_46Binary_46hs_95clearBits_35: (byte 4) */
 	/* PC_NHC_46Binary_46hs_95clearBits_35: (byte 4) */
 	/* ST_v197: (byte 4) */
  bytes2word(105,116,115,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,99,108)
, bytes2word(101,97,114,66)
, bytes2word(105,116,115,35)
, bytes2word(0,0,0,0)
,	/* PS_v201: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95clearBits)
, useLabel(PC_NHC_46Internal_46_95mkIOok2)
,	/* PS_v199: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95clearBits)
, useLabel(PC_NHC_46Binary_46hs_95clearBits)
,	/* PS_v206: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_NHC_46Internal_46_95apply2)
,	/* PS_v205: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_NHC_46Binary_46hs_95clearBits)
,	/* PS_v203: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_NHC_46Binary_46clearBits)
,	/* PS_v208: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v207: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_LAMBDA194)
,	/* PS_v196: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95clearBits_35)
, useLabel(PC_NHC_46Binary_46hs_95clearBits_35)
,	/* PS_v212: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_LAMBDA194)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v210: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_LAMBDA194)
, useLabel(PC_LAMBDA194)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_clearBits" NHC.Binary.hs_clearBits# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_clearBits(void*,HsInt);
#ifdef PROFILE
static SInfo pf_hs_clearBits = {"NHC.Binary","NHC.Binary.hs_clearBits#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95clearBits_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_clearBits(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_clearBits);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Binary/ClearBits.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+12)
#define CT_v202	((void*)startLabel+40)
#define F0_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+48)
#define FN_NHC_46Binary_46hs_95clearBits	((void*)startLabel+76)
#define CT_v206	((void*)startLabel+128)
#define CF_NHC_46Binary_46hs_95clearBits	((void*)startLabel+136)
#define CT_v213	((void*)startLabel+312)
#define FN_LAMBDA198	((void*)startLabel+364)
#define CT_v217	((void*)startLabel+416)
#define F0_LAMBDA198	((void*)startLabel+424)
#define ST_v208	((void*)startLabel+448)
#define PP_LAMBDA198	((void*)startLabel+469)
#define PC_LAMBDA198	((void*)startLabel+469)
#define ST_v215	((void*)startLabel+469)
#define PP_NHC_46Binary_46hs_95clearBits	((void*)startLabel+502)
#define PC_NHC_46Binary_46hs_95clearBits	((void*)startLabel+502)
#define ST_v204	((void*)startLabel+502)
#define PP_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+526)
#define PC_NHC_46Binary_46hs_95clearBits_35	((void*)startLabel+526)
#define ST_v201	((void*)startLabel+526)
#define PS_v205	((void*)startLabel+552)
#define PS_v203	((void*)startLabel+564)
#define PS_v210	((void*)startLabel+576)
#define PS_v209	((void*)startLabel+588)
#define PS_v207	((void*)startLabel+600)
#define PS_v212	((void*)startLabel+612)
#define PS_v211	((void*)startLabel+624)
#define PS_v200	((void*)startLabel+636)
#define PS_v216	((void*)startLabel+648)
#define PS_v214	((void*)startLabel+660)
void FR_NHC_46Binary_46hs_95clearBits_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46Binary[];
extern Node PC_NHC_46Internal_46_95mkIOok2[];
extern Node PC_NHC_46Internal_46_95apply2[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v202)
,	/* FN_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v201)
,	/* CT_v202: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46Binary_46hs_95clearBits_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits_35),2)
, useLabel(PS_v200)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v206)
,	/* FN_NHC_46Binary_46hs_95clearBits: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v205)
, 0
, 0
, 0
, 0
, 110001
, useLabel(ST_v204)
,	/* CT_v206: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95clearBits: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, useLabel(PS_v203)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46Binary_46hs_95clearBits_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v213)
,};
Node FN_NHC_46Binary_46clearBits[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(18,HEAP_OFF_N1,11,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v212)
, 0
, 0
, 0
, 0
, useLabel(PS_v211)
, 0
, 0
, 0
, 0
, useLabel(PS_v210)
, 0
, 0
, 0
, 0
, useLabel(PS_v209)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v208)
,	/* CT_v213: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46Binary_46clearBits[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46clearBits),2)
, useLabel(PS_v207)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95clearBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA198),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v217)
,	/* FN_LAMBDA198: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v216)
, 0
, 0
, 0
, 0
, 150011
, useLabel(ST_v215)
,	/* CT_v217: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA198: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA198),1)
, useLabel(PS_v214)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_NHC_46Binary_46clearBits[] = {
 };
Node PC_NHC_46Binary_46clearBits[] = {
 	/* ST_v208: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,99)
, bytes2word(108,101,97,114)
, bytes2word(66,105,116,115)
,	/* PP_LAMBDA198: (byte 1) */
 	/* PC_LAMBDA198: (byte 1) */
 	/* ST_v215: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(97,114,121,46)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
, bytes2word(115,58,49,53)
, bytes2word(58,49,49,45)
, bytes2word(49,53,58,51)
,	/* PP_NHC_46Binary_46hs_95clearBits: (byte 2) */
 	/* PC_NHC_46Binary_46hs_95clearBits: (byte 2) */
 	/* ST_v204: (byte 2) */
  bytes2word(49,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,97,114,121)
, bytes2word(46,104,115,95)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
,	/* PP_NHC_46Binary_46hs_95clearBits_35: (byte 2) */
 	/* PC_NHC_46Binary_46hs_95clearBits_35: (byte 2) */
 	/* ST_v201: (byte 2) */
  bytes2word(115,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,97,114,121)
, bytes2word(46,104,115,95)
, bytes2word(99,108,101,97)
, bytes2word(114,66,105,116)
, bytes2word(115,35,0,0)
,	/* PS_v205: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95clearBits)
, useLabel(PC_NHC_46Internal_46_95mkIOok2)
,	/* PS_v203: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95clearBits)
, useLabel(PC_NHC_46Binary_46hs_95clearBits)
,	/* PS_v210: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_NHC_46Internal_46_95apply2)
,	/* PS_v209: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_NHC_46Binary_46hs_95clearBits)
,	/* PS_v207: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_NHC_46Binary_46clearBits)
,	/* PS_v212: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v211: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46clearBits)
, useLabel(PC_LAMBDA198)
,	/* PS_v200: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95clearBits_35)
, useLabel(PC_NHC_46Binary_46hs_95clearBits_35)
,	/* PS_v216: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_LAMBDA198)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v214: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_LAMBDA198)
, useLabel(PC_LAMBDA198)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_clearBits" NHC.Binary.hs_clearBits# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_clearBits(void*,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46Binary_46hs_95clearBits_35 = {"NHC.Binary","NHC.Binary.hs_clearBits#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95clearBits_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_clearBits(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46Binary_46hs_95clearBits_35);
  C_RETURN(nodeptr);
}
